==> huaweicloudsdkcdm-3.1.139-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/show_flavors_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFlavorsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'datastore_id': 'str'
    }

    attribute_map = {
        'datastore_id': 'datastore_id'
    }

    def __init__(self, datastore_id=None):
        """ShowFlavorsRequest

        The model defined in huaweicloud sdk

        :param datastore_id: 版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。
        :type datastore_id: str
        """
        
        

        self._datastore_id = None
        self.discriminator = None

        self.datastore_id = datastore_id

    @property
    def datastore_id(self):
        """Gets the datastore_id of this ShowFlavorsRequest.

        版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。

        :return: The datastore_id of this ShowFlavorsRequest.
        :rtype: str
        """
        return self._datastore_id

    @datastore_id.setter
    def datastore_id(self, datastore_id):
        """Sets the datastore_id of this ShowFlavorsRequest.

        版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。

        :param datastore_id: The datastore_id of this ShowFlavorsRequest.
        :type datastore_id: str
        """
        self._datastore_id = datastore_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFlavorsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdm-3.1.150-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/show_flavors_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFlavorsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'datastore_id': 'str'
    }

    attribute_map = {
        'datastore_id': 'datastore_id'
    }

    def __init__(self, datastore_id=None):
        r"""ShowFlavorsRequest

        The model defined in huaweicloud sdk

        :param datastore_id: 版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。
        :type datastore_id: str
        """
        
        

        self._datastore_id = None
        self.discriminator = None

        self.datastore_id = datastore_id

    @property
    def datastore_id(self):
        r"""Gets the datastore_id of this ShowFlavorsRequest.

        版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。

        :return: The datastore_id of this ShowFlavorsRequest.
        :rtype: str
        """
        return self._datastore_id

    @datastore_id.setter
    def datastore_id(self, datastore_id):
        r"""Sets the datastore_id of this ShowFlavorsRequest.

        版本ID，获取方法请参见[CDM支持的版本](ShowDatastores.xml)。

        :param datastore_id: The datastore_id of this ShowFlavorsRequest.
        :type datastore_id: str
        """
        self._datastore_id = datastore_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFlavorsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
